#!/usr/bin/env bash
set -ex

ROOT_PATH="/.bottlerocket/rootfs"
UNFORMATTED_DISK=$(lsblk --fs --json | jq -r '.blockdevices[] | select(.children == null and .fstype == null) | .name'| grep -i "nvme" | head -1)

# Exit early if there are no unformatted disks
if [ -z "${UNFORMATTED_DISK}" ]; then
  echo "unformatted disk not found"
  exit 0
fi

# Create a partition
parted -s ${ROOT_PATH}/dev/${UNFORMATTED_DISK} mklabel gpt
parted -s ${ROOT_PATH}/dev/${UNFORMATTED_DISK} mkpart primary 0% 100%

# Format the partition
mkfs -t xfs -q -f ${ROOT_PATH}/dev/${UNFORMATTED_DISK}p1

# Mount the partition
mkdir ${ROOT_PATH}/mnt/tenant
mount ${ROOT_PATH}/dev/${UNFORMATTED_DISK}p1 ${ROOT_PATH}/mnt/tenant

# Make the mount point world-writable.
chmod 777 ${ROOT_PATH}/mnt/tenant
