#!/usr/bin/env bash
set -ex

ROOT_PATH="/.bottlerocket/rootfs"
EPHEMERAL_DISK_PATH="${ROOT_PATH}/dev/disk/ephemeral"

# Symlinks to ephemeral disks are created here by udev
declare -a EPHEMERAL_DISKS
EPHEMERAL_DISKS=("${EPHEMERAL_DISK_PATH}"/*)

# Exit early if there aren't ephemeral disks
if [ ! -d "${EPHEMERAL_DISK_PATH}" ] || [ "${#EPHEMERAL_DISKS[@]}" -eq 0 ]; then
  echo "no ephemeral disks found"
  exit 0
fi

MD_NAME="tenant"
MD_DEVICE="/dev/md/${MD_NAME}"
MD_CONFIG="/.bottlerocket/bootstrap-containers/current/mdadm.conf"

# Create or assemble the array.
if [ ! -s "${MD_CONFIG}" ] ; then
  mdadm --create --force --verbose \
    "${MD_DEVICE}" \
      --level=0 \
      --name="${MD_NAME}" \
      --raid-devices="${#EPHEMERAL_DISKS[@]}" \
      "${EPHEMERAL_DISKS[@]}"
  mdadm --detail --scan > "${MD_CONFIG}"
else
  mdadm --assemble --config="${MD_CONFIG}" "${MD_DEVICE}"
fi

# Format the array if not already formatted.
if ! blkid --match-token TYPE=xfs "${MD_DEVICE}" ; then
  mkfs.xfs "${MD_DEVICE}"
fi

MOUNT_POINT="${ROOT_PATH}/mnt/${MD_NAME}"

# Mount the array in the host's /mnt.
mkdir -p "${MOUNT_POINT}"
mount "${MD_DEVICE}" "${MOUNT_POINT}"

# Make the mount point world-writable.
chmod 777 "${MOUNT_POINT}"
